# Sankhyaakaara

## Convert numbers to words in Sanskrit!

### Installation

```bash
pip install sankhyaakaara
```

### Usage

```python
from sankhyaakaara import convert

num = 123456789
word = convert(num)
print(word)
```

### Web App

You can also use the web app to convert numbers to words in Sanskrit. [Sankhyaakaara Web App](https://sankhya.streamlit.app)
